==> data-engine-api-3.11-sources.jar: org/odpi/openmetadata/accessservices/dataengine/event/EventTypeEvent.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.dataengine.event;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import org.odpi.openmetadata.accessservices.dataengine.model.EventType;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * The event type event of Data Engine OMAS.
 */
@JsonAutoDetect(getterVisibility = PUBLIC_ONLY, setterVisibility = PUBLIC_ONLY, fieldVisibility = NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
@EqualsAndHashCode(callSuper = true)
@ToString
public class EventTypeEvent extends DataEngineEventHeader {
    /**
     * The event type to be created
     * -- GETTER --
     * Return the event type bean
     *
     * @return the event type
     * -- SETTER --
     * Set up the event type bean
     * @param eventType the event type
     */
    private EventType eventType;

    /**
     * The topic qualified name to which the event type will be linked
     * -- GETTER --
     * Return the topic qualified name to which the event type will be linked
     *
     * @return the topic qualified name
     * -- SETTER --
     * Set up the topic qualified name to which the event type will be linked
     * @param topicQualifiedName the topic qualified name
     */
    private String topicQualifiedName;
}

==> data-engine-api-3.15-sources.jar: org/odpi/openmetadata/accessservices/dataengine/event/EventTypeEvent.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.dataengine.event;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import org.odpi.openmetadata.accessservices.dataengine.model.EventType;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * The event type event of Data Engine OMAS.
 */
@JsonAutoDetect(getterVisibility = PUBLIC_ONLY, setterVisibility = PUBLIC_ONLY, fieldVisibility = NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
@EqualsAndHashCode(callSuper = true)
@ToString
public class EventTypeEvent extends DataEngineEventHeader {

    /**
     * Serial version UID
     * -- GETTER --
     * Gets the serial version UID
     * @return the serial version UID
     * -- SETTER --
     * Sets the serial version UID
     * @param serialVersionUID the serial version UID
     */
    private static final long serialVersionUID = 1L;

    /**
     * The event type to be created
     * -- GETTER --
     * Return the event type bean
     *
     * @return the event type
     * -- SETTER --
     * Set up the event type bean
     * @param eventType the event type
     */
    private EventType eventType;

    /**
     * The topic qualified name to which the event type will be linked
     * -- GETTER --
     * Return the topic qualified name to which the event type will be linked
     *
     * @return the topic qualified name
     * -- SETTER --
     * Set up the topic qualified name to which the event type will be linked
     * @param topicQualifiedName the topic qualified name
     */
    private String topicQualifiedName;
}
